==> openbabel_3.0.0+dfsg.orig.tar.xz: openbabel-3.0.0/README.md <==
Open Babel
----------

[![GitHub release](https://img.shields.io/github/release/openbabel/openbabel.svg?maxAge=86400)](https://sourceforge.net/projects/openbabel/files/latest/download)
[![Download Open Babel](https://img.shields.io/sourceforge/dt/openbabel.svg?maxAge=86400)](https://sourceforge.net/projects/openbabel/files/latest/download)
[![Travis CI](https://img.shields.io/travis/openbabel/openbabel.svg)](https://travis-ci.org/openbabel/openbabel)
[![Google Scholar Citations](https://openbabel.org/citations.svg?maxAge=86400)](https://scholar.google.com/scholar?oi=bibs&hl=en&cites=13319995025871922899&as_sdt=5)

Open Babel is a chemical toolbox designed to speak the many languages
of chemical data. It's an open, collaborative project allowing anyone
to search, convert, analyze, or store data from molecular modeling,
chemistry, solid-state materials, biochemistry, or related areas.

* Ready-to-use programs, and complete programmer's toolkit
* Read, write and convert over 90 chemical file formats
* Filter and search molecular files using SMARTS and other methods
* Generate 2D and 3D coordinates for SMILES, InChI and other formats
* Supports molecular modeling, cheminformatics, bioinformatics,
  organic chemistry, inorganic chemistry, solid-state materials,
  nuclear chemistry...

Open Babel is distributed under the GNU General Public License (GPL).
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 2 of the License. Full details
can be found in the file "COPYING" which should be included in your
distribution.

For more information, check the [Open Babel website](http://openbabel.org/).

==> openbabel_3.1.1+dfsg.orig.tar.xz: openbabel-3.1.1/README.md <==
Open Babel
----------

[![GitHub release](https://img.shields.io/github/release/openbabel/openbabel.svg?maxAge=86400)](https://github.com/openbabel/openbabel/releases)
[![Download Open Babel](https://img.shields.io/sourceforge/dt/openbabel.svg?maxAge=86400)](https://github.com/openbabel/openbabel/releases)
[![Travis CI](https://img.shields.io/travis/openbabel/openbabel.svg)](https://travis-ci.org/openbabel/openbabel)
[![Google Scholar Citations](https://openbabel.org/citations.svg?maxAge=86400)](https://scholar.google.com/scholar?oi=bibs&hl=en&cites=13319995025871922899&as_sdt=5)

Open Babel is a chemical toolbox designed to speak the many languages
of chemical data. It's an open, collaborative project allowing anyone
to search, convert, analyze, or store data from molecular modeling,
chemistry, solid-state materials, biochemistry, or related areas.

* Ready-to-use programs, and complete programmer's toolkit
* Read, write and convert over 90 chemical file formats
* Filter and search molecular files using SMARTS and other methods
* Generate 2D and 3D coordinates for SMILES, InChI and other formats
* Supports molecular modeling, cheminformatics, bioinformatics,
  organic chemistry, inorganic chemistry, solid-state materials,
  nuclear chemistry...

Open Babel is distributed under the GNU General Public License (GPL).
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation version 2 of the License. Full details
can be found in the file "COPYING" which should be included in your
distribution.

For more information, check the [Open Babel website](http://openbabel.org/).
